Integrating with Django Categories — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Integrating with Django Categories

- Table of Contents
- index
  modules
  next
  previous

# Integrating with Django Categories

## Install django-categories

1. Install `django-categories`

   >     $ pip install django-categories

2. Add `categories` to your `INSTALLED_APPS` setting.

   >     INSTALLED_APPS = (
   >         ...
   >         'categories',
   >         ...
   >     )

3. Supply the fields you want to be added to the `Story` model.

   >     CATEGORIES_SETTINGS = {
   >         ...
   >         'FK_REGISTRY': {
   >             'stories.story': {
   >             'name': 'primary_category', 'related_name': 'primary_category'
   >             }
   >         },
   >         'M2M_REGISTRY': {
   >             'stories.story': {
   >             'name': 'categories', 'related_name': 'categories'
   >             }
   >         }
   >         ...
   >     }

   > In this case, 2 fields are setup, one `ForeignKey` field called primary_category and one `ManyToMany` field called categories

4. Sync your database

   >     $ ./manage.py syncdb

   > or if your using `South`

   >     $ ./manage.py syncdb --migrate